Particle System
***************

.. figure:: images/particle_system.png
	:scale: 50 %
	:alt: particle_system
	:align: center
	:figclass: align-center

	Particle System

.. literalinclude:: ../../examples/GLWindow/particle_system.py
	:linenos:
